{% load templatetag_handlebars %}                                               
{% tplhandlebars "calculator-addrow-tmpl" %}
<li id="gp-calculator-add-row" class="gp-calculator-add-row-container">
    <a href="#" title="{{ trans "calculator_addrow_title" }}" tabindex="0">{{ trans "calculator_addrow" }}</a>
    <span class="pull-right" style="margin-right:3em;"><i class="fa fa-ellipsis-v fa-lg"></i></span>
</li>
{% endtplhandlebars %}
